@@ -2,11 +2,11 @@ import re
 
 from django.db import models
 from django.core.validators import RegexValidator
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy
 from django.utils.six import with_metaclass
 
 label_re = re.compile(r'(?i)^[a-z0-9][a-z0-9-]*[a-z0-9]$')
-validate_label = RegexValidator(label_re, _("Enter a valid instance label consisting of letters, numbers, or hyphens."), 'invalid')
+validate_label = RegexValidator(label_re, ugettext_lazy("Enter a valid instance label consisting of letters, numbers, or hyphens."), 'invalid')
 
 from south.modelsinspector import add_introspection_rules
 add_introspection_rules([], ["^instances\.fields\.DNSLabelField"])
